@@ -89,7 +89,7 @@ setMethodS3("createLink", "default", function(link=".", target, skip=!overwrite,
     if (skip) {
       res <- Arguments$getReadablePathname(link, mustExist=TRUE);
 
-      resA <- getAbsolutePath(Sys.readlink2(res))
+      resA <- getAbsolutePath(Sys.readlink2(res, what="corrected"))
       equal <- identical(resA, target)
       # Be more forgiving on Windows system, i.e. assume a
       # case-insensitive file system
@@ -118,7 +118,7 @@ setMethodS3("createLink", "default", function(link=".", target, skip=!overwrite,
 
 
   # Keep only 'methods' that are supported on the current platform
-  if (.Platform$OS != "windows") {
+  if (.Platform$OS.type != "windows") {
     methods <- grep("windows-", methods, value=TRUE, invert=TRUE);
   }
 
