@@ -29,8 +29,8 @@
 # @author
 #
 # \seealso{
-#   @see "createWindowsShortcut"
-#   \code{\link{filePath}}
+#   @see "createWindowsShortcut" and
+#   \code{\link{filePath}()}
 # }
 #
 # \references{
@@ -46,7 +46,7 @@
 #       April 2008. \url{http://wiki.tcl.tk/1844} \cr
 #   [6] Daniel S. Bensen, \emph{Shortcut File Format (.lnk)}, Stdlib.com,
 #       April 24, 2009. \cr
-#       \url{http://www.stdlib.com/art6-Shortcut-File-Format-lnk.html}
+#       \url{https://web.archive.org/web/20110817051855/http://www.stdlib.com/art6-Shortcut-File-Format-lnk.html} (was http://www.stdlib.com/art6-Shortcut-File-Format-lnk.html)\cr
 #   [7] [MS-SHLLINK]: Shell Link (.LNK) Binary File Format, Microsoft Inc.,
 #       September 25, 2009. \cr
 # }
@@ -398,7 +398,7 @@ setMethodS3("readWindowsShortcut", "default", function(con, verbose=FALSE, ...)
       }
 
       table$volumeLabel <- readString(con);
-      table$.offset <- table$.offset + nchar(table$volumeLabel) + 1;
+      table$.offset <- table$.offset + nchar(table$volumeLabel, type="chars") + 1;
 
       if (table$.offset != table$length) {
         stop("File format error: Length of structure did not match the number of bytes read.");
@@ -431,7 +431,7 @@ setMethodS3("readWindowsShortcut", "default", function(con, verbose=FALSE, ...)
       fileLocationInfo$.offset <- fileLocationInfo$.offset + skip;
       fileLocationInfo$basePathname <- readString(con);
       fileLocationInfo$.offset <- fileLocationInfo$.offset +
-                                    nchar(fileLocationInfo$basePathname) + 1;
+                      nchar(fileLocationInfo$basePathname, type="chars") + 1;
 
       if (verbose) {
         message("basePathname='", fileLocationInfo$basePathname, "'");
@@ -483,7 +483,7 @@ setMethodS3("readWindowsShortcut", "default", function(con, verbose=FALSE, ...)
       }
 
       table$networkShareName <- readString(con);
-      table$.offset <- table$.offset + nchar(table$networkShareName) + 1;
+      table$.offset <- table$.offset + nchar(table$networkShareName, type="chars") + 1;
 
       if (verbose) {
         message("File location info / Network Volume Table:");
@@ -523,7 +523,7 @@ setMethodS3("readWindowsShortcut", "default", function(con, verbose=FALSE, ...)
 
     fileLocationInfo$remainingPathname <- readString(con);
     fileLocationInfo$.offset <- fileLocationInfo$.offset +
-                             nchar(fileLocationInfo$remainingPathname) + 1;
+               nchar(fileLocationInfo$remainingPathname, type="chars") + 1;
 
 
     if (fileLocationInfo$length != fileLocationInfo$.offset) {
